@@ -2,25 +2,27 @@
 from __future__ import unicode_literals
 
 MESSAGES = {
-    "Also available in": "Ook beschikbaar in",
+    "%d min remaining to read": "%d min resterende leestijd ",
     "Also available in:": "Ook beschikbaar in:",
     "Archive": "Archief",
     "Categories": "Categorieën",
+    "Comments": "Commentaar",
     "LANGUAGE": "Nederlands",
+    "Languages:": "Talen:",
     "More posts about %s": "Meer berichten over %s",
-    "More posts about": "Meer berichten over",
     "Newer posts": "Nieuwere berichten",
     "Next post": "Volgend bericht",
-    "No posts found.": "",
-    "Nothing found.": "",
+    "No posts found.": "Geen berichten gevonden.",
+    "Nothing found.": "Niets gevonden.",
     "Older posts": "Oudere berichten",
     "Original site": "Originele site",
-    "Posted": "Geplaatst",
     "Posted:": "Geplaatst:",
     "Posts about %s": "Berichten over %s",
     "Posts for year %s": "Berichten voor het jaar %s",
     "Posts for {month} {year}": "Berichten voor {month} {year}",
     "Previous post": "Vorig bericht",
+    "Publication date": "Publicatiedatum",
+    "RSS feed": "RSS-feed",
     "Read in English": "Lees in het Nederlands",
     "Read more": "Lees verder",
     "Source": "Bron",
