@@ -453,7 +453,7 @@ class Nikola(object):
 
         # Disable RSS.  For a successful disable, we must have both the option
         # false and the plugin disabled through the official means.
-        if 'generate_rss' in self.config['DISABLED_PLUGINS']:
+        if 'generate_rss' in self.config['DISABLED_PLUGINS'] and self.config['GENERATE_RSS'] is True:
             self.config['GENERATE_RSS'] = False
 
         if not self.config['GENERATE_RSS'] and 'generate_rss' not in self.config['DISABLED_PLUGINS']:
@@ -469,12 +469,12 @@ class Nikola(object):
         self.default_lang = self.config['DEFAULT_LANG']
         self.translations = self.config['TRANSLATIONS']
 
-        locale_fallback, locale_default, locales = sanitized_locales(
-                                    self.config.get('LOCALE_FALLBACK', None),
-                                    self.config.get('LOCALE_DEFAULT', None),
-                                    self.config.get('LOCALES', {}),
-                                    self.translations)  # NOQA
-        utils.LocaleBorg.initialize(locales, self.default_lang)
+        if self.configured:
+            locale_fallback, locale_default, locales = sanitized_locales(
+                self.config.get('LOCALE_FALLBACK', None),
+                self.config.get('LOCALE_DEFAULT', None),
+                self.config.get('LOCALES', {}), self.translations)
+            utils.LocaleBorg.initialize(locales, self.default_lang)
 
         # BASE_URL defaults to SITE_URL
         if 'BASE_URL' not in self.config:
@@ -578,7 +578,10 @@ class Nikola(object):
         self._GLOBAL_CONTEXT['url_type'] = self.config['URL_TYPE']
         self._GLOBAL_CONTEXT['timezone'] = self.tzinfo
         self._GLOBAL_CONTEXT['_link'] = self.link
-        self._GLOBAL_CONTEXT['set_locale'] = utils.LocaleBorg().set_locale
+        try:
+            self._GLOBAL_CONTEXT['set_locale'] = utils.LocaleBorg().set_locale
+        except utils.LocaleBorgUninitializedException:
+            self._GLOBAL_CONTEXT['set_locale'] = None
         self._GLOBAL_CONTEXT['rel_link'] = self.rel_link
         self._GLOBAL_CONTEXT['abs_link'] = self.abs_link
         self._GLOBAL_CONTEXT['exists'] = self.file_exists
@@ -1228,6 +1231,9 @@ class Nikola(object):
         self._scanned = True
         if not self.quiet:
             print("done!", file=sys.stderr)
+
+        signal('scanned').send(self)
+
         if quit:
             sys.exit(1)
 
@@ -1265,6 +1271,9 @@ class Nikola(object):
         for k, v in self.GLOBAL_CONTEXT['template_hooks'].items():
             deps_dict['||template_hooks|{0}||'.format(k)] = v._items
 
+        for k in self._GLOBAL_CONTEXT_TRANSLATABLE:
+            deps_dict[k] = deps_dict['global'][k](lang)
+
         if post:
             deps_dict['post_translations'] = post.translated_to
 
@@ -1303,6 +1312,9 @@ class Nikola(object):
         for k, v in self.GLOBAL_CONTEXT['template_hooks'].items():
             deps_context['||template_hooks|{0}||'.format(k)] = v._items
 
+        for k in self._GLOBAL_CONTEXT_TRANSLATABLE:
+            deps_context[k] = deps_context['global'][k](lang)
+
         task = {
             'name': os.path.normpath(output_name),
             'targets': [output_name],
